Message

Struct Message 

pub struct Message<T> {
    pub property: Property,
    pub values: [T; 4],
}
A SPE message describing a change in properties at one point in time.

Fields

property: Propertyvalues: [T; 4]

Only values relevant to the property need to be stored.

Implementations

Source

impl<T: Default + Copy> Message<T>

pub fn new<const N: usize>(property: Property, values: [T; N]) -> Self

Create a new SPE message using a Property and array of values.

N must be no more than four.

pub fn position(axis: &AxisCombo, position: [T; 3]) -> Message<T>

Create a new SPE position message.

pub fn extent(axis: &AxisCombo, extent: [T; 3]) -> Message<T>

Create a new SPE extent message.

pub fn pos_x(x: T) -> Message<T>

pub fn pos_y(y: T) -> Message<T>

pub fn pos_z(z: T) -> Message<T>

pub fn pos_xy(x: T, y: T) -> Message<T>

pub fn pos_xz(x: T, z: T) -> Message<T>

pub fn pos_yz(y: T, z: T) -> Message<T>

pub fn pos_xyz(x: T, y: T, z: T) -> Message<T>

pub fn ext_x(x: T) -> Message<T>

pub fn ext_y(y: T) -> Message<T>

pub fn ext_z(z: T) -> Message<T>

pub fn ext_xy(x: T, y: T) -> Message<T>

pub fn ext_xz(x: T, z: T) -> Message<T>

pub fn ext_yz(y: T, z: T) -> Message<T>

pub fn ext_xyz(x: T, y: T, z: T) -> Message<T>

pub fn values(&self) -> &[T]